'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var helper = require('@tarojs/helper');
var node_path = require('node:path');
var fsExtra = require('fs-extra');
var AutoImport = require('unplugin-auto-import/webpack');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var AutoImport__default = /*#__PURE__*/_interopDefaultLegacy(AutoImport);

const metaDataPath = 'taro-hooks/metadata.json';
var index = (ctx, options) => {
    if (!getPkgPath(metaDataPath))
        return;
    ctx.modifyWebpackChain(({ chain }) => {
        console.log(helper.chalk.blue(`✨ auto-import 帮助你更轻松的使用 taro-hooks！`));
        const defaultDtsPath = node_path.resolve(ctx.paths.sourcePath, 'auto-imports.d.ts');
        const { include = [], imports = [], dts = defaultDtsPath, ...extraOptions } = options ?? {};
        chain.plugin('plugin-auto-import').use(AutoImport__default["default"]({
            include: [
                // @ts-ignore
                ...include,
                /\.[tj]sx?$/,
                /\.vue$/,
                /\.vue\?vue/, // .vue
            ],
            imports: [
                // @ts-ignore
                ...imports,
                autoImportPresets(),
            ],
            dts,
            ...extraOptions,
        }));
    });
};
function autoImportPresets() {
    const metadataFilePath = getPkgPath(metaDataPath);
    const metadata = fsExtra.readJSONSync(metadataFilePath);
    return {
        'taro-hooks': metadata.functions.flatMap(({ name, alias = [] }) => [
            name,
            ...alias,
        ]),
    };
}
function getPkgPath(pkg) {
    try {
        return require.resolve(pkg, {
            paths: [process.cwd()],
        });
    }
    catch (error) {
        console.log(helper.chalk.yellow(`找不到 ${pkg}. 请先安装`));
        process.exit(1);
    }
}

exports.autoImportPresets = autoImportPresets;
exports["default"] = index;
exports.getPkgPath = getPkgPath;
//# sourceMappingURL=index.js.map
